summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorLuc Verhaegen <libv@skynet.be>2009-07-21 01:44:45 +0000
committerLuc Verhaegen <libv@skynet.be>2009-07-21 01:44:45 +0000
commit11793770600560ffa185871ae1906413eec70674 (patch)
treea2d29bd9f158a7fd9c66809d96d2cada7ab82872
parent322f3050336e026bc053cf68616cfce86cf2a0a9 (diff)
downloadast2050-flashrom-11793770600560ffa185871ae1906413eec70674.zip
ast2050-flashrom-11793770600560ffa185871ae1906413eec70674.tar.gz
Board enable for Aopen VKM400 AM-S
This board is a VIA KM400 and VT8237 and IT8705F superio. Corresponding to flashrom svn r655. Signed-off-by: Luc Verhaegen <libv@skynet.be> Acked-by: Scott Johnson <scott@gnuveau.net>
-rw-r--r--board_enable.c29
1 files changed, 24 insertions, 5 deletions
diff --git a/board_enable.c b/board_enable.c
index 4d4f719..b094e9b 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -636,10 +636,10 @@ static int board_kontron_986lcd_m(const char *name)
/**
* Suited for:
* - Biostar P4M80-M4: Intel P4 + VIA P4M800 + VT8237
* - GIGABYTE GA-7VT600: AMD K7 + VIA KT600 + VT8237
*/
-static int board_biostar_p4m80_m4(const char *name)
+static int it8705_rom_write_enable(const char *name)
{
/* enter IT87xx conf mode */
enter_conf_mode_ite(0x2e);
@@ -659,6 +659,24 @@ static int board_biostar_p4m80_m4(const char *name)
}
/**
+ * Suited for A-Open vKM400 AM-S: VIA KM400 + VT8237 + IT8705F.
+ */
+static int board_aopen_vkm400(const char *name)
+{
+ struct pci_dev *dev;
+
+ dev = pci_dev_find(0x1106, 0x3227); /* VT8237 ISA bridge */
+ if (!dev) {
+ fprintf(stderr, "\nERROR: VT8237 ISA bridge not found.\n");
+ return -1;
+ }
+
+ vt823x_set_all_writes_to_lpc(dev);
+
+ return it8705_rom_write_enable(name);
+}
+
+/**
* Winbond W83697HF Super I/O + VIA VT8235 southbridge
*
* Suited for:
@@ -896,18 +914,19 @@ struct board_pciid_enable board_pciid_enables[] = {
{0x8086, 0x1130, 0, 0, 0x105a, 0x0d30, 0x105a, 0x4d33, "acorp", "6a815epd", "Acorp", "6A815EPD", board_acorp_6a815epd},
{0x1022, 0x746B, 0x1022, 0x36C0, 0, 0, 0, 0, "AGAMI", "ARUMA", "agami", "Aruma", w83627hf_gpio24_raise_2e},
{0x1106, 0x3177, 0x17F2, 0x3177, 0x1106, 0x3148, 0x17F2, 0x3148, NULL, NULL, "Albatron", "PM266A*", board_epox_ep_8k5a2},
+ {0x1106, 0x3205, 0x1106, 0x3205, 0x10EC, 0x8139, 0xA0A0, 0x0477, NULL, NULL, "AOpen", "vKM400 AM-s", board_aopen_vkm400},
{0x1022, 0x2090, 0, 0, 0x1022, 0x2080, 0, 0, "artecgroup", "dbe61", "Artec Group", "DBE61", board_artecgroup_dbe6x},
{0x1022, 0x2090, 0, 0, 0x1022, 0x2080, 0, 0, "artecgroup", "dbe62", "Artec Group", "DBE62", board_artecgroup_dbe6x},
{0x1106, 0x3189, 0x1043, 0x807F, 0x1106, 0x3177, 0x1043, 0x808C, NULL, NULL, "ASUS", "A7V8X", board_asus_a7v8x},
{0x1106, 0x3177, 0x1043, 0x80A1, 0x1106, 0x3205, 0x1043, 0x8118, NULL, NULL, "ASUS", "A7V8X-MX SE", board_asus_a7v8x_mx},
{0x8086, 0x1a30, 0x1043, 0x8070, 0x8086, 0x244b, 0x1043, 0x8028, NULL, NULL, "ASUS", "P4B266", ich2_gpio22_raise},
{0x10B9, 0x1541, 0, 0, 0x10B9, 0x1533, 0, 0, "asus", "p5a", "ASUS", "P5A", board_asus_p5a},
- {0x1106, 0x3149, 0x1565, 0x3206, 0x1106, 0x3344, 0x1565, 0x1202, NULL, NULL, "Biostar", "P4M80-M4", board_biostar_p4m80_m4},
+ {0x1106, 0x3149, 0x1565, 0x3206, 0x1106, 0x3344, 0x1565, 0x1202, NULL, NULL, "Biostar", "P4M80-M4", it8705_rom_write_enable},
{0x1106, 0x3038, 0x1019, 0x0996, 0x1106, 0x3177, 0x1019, 0x0996, NULL, NULL, "Elitegroup", "K7VTA3", it8705f_write_enable_2e},
{0x1106, 0x3177, 0x1106, 0x3177, 0x1106, 0x3059, 0x1695, 0x3005, NULL, NULL, "EPoX", "EP-8K5A2", board_epox_ep_8k5a2},
{0x8086, 0x7110, 0, 0, 0x8086, 0x7190, 0, 0, "epox", "ep-bx3", "EPoX", "EP-BX3", board_epox_ep_bx3},
{0x1039, 0x0761, 0, 0, 0, 0, 0, 0, "gigabyte", "2761gxdk", "GIGABYTE", "GA-2761GXDK", it87xx_probe_spi_flash},
- {0x1106, 0x3227, 0x1458, 0x5001, 0x10ec, 0x8139, 0x1458, 0xe000, NULL, NULL, "GIGABYTE", "GA-7VT600", board_biostar_p4m80_m4},
+ {0x1106, 0x3227, 0x1458, 0x5001, 0x10ec, 0x8139, 0x1458, 0xe000, NULL, NULL, "GIGABYTE", "GA-7VT600", it8705_rom_write_enable},
{0x10DE, 0x0050, 0x1458, 0x0C11, 0x10DE, 0x005e, 0x1458, 0x5000, NULL, NULL, "GIGABYTE", "GA-K8N-SLI", board_ga_k8n_sli},
{0x10de, 0x0360, 0, 0, 0, 0, 0, 0, "gigabyte", "m57sli", "GIGABYTE", "GA-M57SLI-S4", it87xx_probe_spi_flash},
{0x10de, 0x03e0, 0, 0, 0, 0, 0, 0, "gigabyte", "m61p", "GIGABYTE", "GA-M61P-S3", it87xx_probe_spi_flash},
@@ -636,10 +636,10 @@ static int board_kontron_986lcd_m(const char *name)
/**
* Suited for:
- * - Biostar P4M80-M4: Intel P4 + VIA P4M800 + VT8237
- * - GIGABYTE GA-7VT600: AMD K7 + VIA KT600 + VT8237
+ * - Biostar P4M80-M4: VIA P4M800 + VT8237 + IT8705AF
+ * - GIGABYTE GA-7VT600: VIA KT600 + VT8237 + IT8705
*/
OpenPOWER on IntegriCloud